=====
gpCAM
=====



gpCAM Copyright (c) 2021, The Regents of the University of California,
through Lawrence Berkeley National Laboratory (subject to receipt of
any required approvals from the U.S. Dept. of Energy). All rights reserved.

If you have questions about your rights to use or distribute this software,
please contact Berkeley Lab's Intellectual Property Office at
IPO@lbl.gov.

NOTICE.  This Software was developed under funding from the U.S. Department
of Energy and the U.S. Government consequently retains certain rights.  As
such, the U.S. Government has been granted for itself and others acting on
its behalf a paid-up, nonexclusive, irrevocable, worldwide license in the
Software to reproduce, distribute copies to the public, prepare derivative
works, and perform publicly and display publicly, and to permit others to do so.



===============================================


* Free software: 
* Documentation: https://www.overleaf.com/read/nrcyxxsbhvbx
* website: gpcam.lbl.gov


Features
--------

* gpCAM is a software for autonomous experimentation

Credits
-------

Main Developer: Marcus Noack (MarcusNoack@lbl.gov)
Several people from across the DOE national labs have given insights
that led the code in it's current form.
See "AUTHORS" for more details on that.


